@@ -24,9 +24,9 @@
 #'   columns of `x` and `y`.
 #' @param use_nan if \code{TRUE}, return `NaN` if the standard deviation of a
 #'   vector is zero when `method` is "correlation"; if all the values are zero
-#'   in a vector when `method` is "cosine", "kullback" or "chisquared". Note
-#'   that use of `NaN` makes the similarity/distance matrix denser and therefore
-#'   larger.
+#'   in a vector when `method` is "cosine", "kullback", "jeffreys" or "chisquared".
+#'   Note that use of `NaN` makes the similarity/distance matrix denser and
+#'   therefore larger.
 #' @param digits determines rounding of small values towards zero. Use primarily
 #'   to correct rounding errors in C++. See \link{zapsmall}.
 #' @import methods Matrix
@@ -51,13 +51,13 @@ simil <- function(x, y = NULL, margin = 1,
 
 #' @rdname simil
 #' @param smooth adds a  fixed value to all the cells to avoid division by zero.
-#'   Only used when `method` is "chisquared" or "kullback".
+#'   Only used when `method` is "chisquared", "kullback" or "jeffreys".
 #' @export
 #' @examples
 #' mt <- Matrix::rsparsematrix(100, 100, 0.01)
 #' dist(mt, method = "euclidean")[1:5, 1:5]
 dist <- function(x, y = NULL, margin = 1,
-                 method = c("euclidean", "chisquared", "kullback",
+                 method = c("euclidean", "chisquared", "kullback", "jeffreys",
                             "manhattan", "maximum", "canberra", "minkowski", "hamming"),
                  p = 2, smooth = 0, drop0 = FALSE, diag = FALSE, use_nan = FALSE, digits = 14) {
 
@@ -71,7 +71,7 @@ dist <- function(x, y = NULL, margin = 1,
 proxy <- function(x, y = NULL, margin = 1,
                   method = c("cosine", "correlation", "jaccard", "ejaccard",
                              "dice", "edice", "hamann", "simple matching", "faith",
-                             "euclidean", "chisquared", "kullback",
+                             "euclidean", "chisquared", "kullback", "jeffreys",
                              "manhattan", "maximum", "canberra", "minkowski", "hamming"),
                   p = 2, smooth = 0, min_proxy = NULL, rank = NULL, drop0 = FALSE,
                   diag = FALSE, use_nan = FALSE, digits = 14) {
@@ -108,7 +108,7 @@ proxy <- function(x, y = NULL, margin = 1,
         if (method == "correlation") {
             if (any(colSds(x) == 0) || any(colSds(y) == 0))
                 warning("x or y has vectors with zero standard deviation; consider setting use_nan = TRUE", call. = FALSE)
-        } else if (method %in% c("cosine", "kullback", "chisquared")) {
+        } else if (method %in% c("cosine", "kullback", "chisquared", "jeffreys")) {
             if (any(colZeros(x) == nrow(x)) || any(colZeros(y) == nrow(y)))
                 warning("x or y has vectors with all zero; consider setting use_nan = TRUE", call. = FALSE)
         }
@@ -158,7 +158,8 @@ proxy <- function(x, y = NULL, margin = 1,
             method = match(method, c("cosine", "correlation", "ejaccard", "edice",
                                      "hamann", "simple matching", "faith",
                                      "euclidean", "chisquared", "kullback", "manhattan",
-                                     "maximum", "canberra", "minkowski", "hamming")),
+                                     "maximum", "canberra", "minkowski", "hamming",
+                                     "jeffreys")),
             rank = rank,
             limit = min_proxy,
             weight = weight,
